@@ -401,6 +401,8 @@ aisleriot_window_show_about_dialog (AisleriotWindow * window)
     "Richard Hoelscher http://www.rahga.com/svg",
     /* Anglo-American cards */
     "Aike Reyer",
+    /* Guyenne Classic and Swiss cards */
+    "Mario Frasca <mariotomo@gmail.com>",
     /* FIXMEchpe: who did the Bonded cards? */
     NULL
   };
